function [hdst, ok] = fileheader_lts(filename)
%FILEHEADER_TS Read Lynx AqDados .LTD or .LTX file header.
%   [HDST, OK] = FILEHEADER_TS(FILENAME) reads the header of a Lynx 
%   AqDados .LTD or .LTX file especified in FILENAME.
%   the information is stored in a file created by HdrLTX2Mat4.exe
%   OK returns allawys 0 
%   Lynx AqDados .LTD or .LTX header data is returned in HDST, that is 
%   a struct type 
%
%   To access data in the hdst struct is very simple. For exemple, the
%   name of first active channel is accessed by:
%       hdst.sname(1)
%
%   The list of channels returned in SNAME, SUNIT, LSUP and LINF correspond
%   only to active channel in the .LTD and .LTX file.
%
%   See also LYNXGENG.

if (nargin ~= 1)
    error('Invalid sintaxe! Use help lynxinfo');
    return
end;

if ~isstr(filename)
    error('Filename must be a string argument!');
    return
end

% --- Open AqDados file header exported by HdrLTX2Mat4 ---
[f_path, f_name, f_ext] = fileparts (filename);
filename = strrep (filename, f_ext, '.mat');
load (filename);

% --- build sname and sunit ---
l_name= l_name';   % transpose these arrays
l_unit= l_unit';   
sname = {};
sunit = {};
for i = 1 : l_nc
    sname = [sname, {deblank(l_name (i,:))}];
    sunit = [sunit, {deblank(l_unit (i,:))}];
end    

hdst = struct ('nc', l_nc, 'fs', l_fs, 'ns', l_ns, 'FileOfs', l_FileOfs,...
               'sname', {sname}, 'sunit', {sunit}, 'lsup', l_sup, 'linf', l_inf, ...
               'comment', l_comment', 'SampleFormat', SampleFormat', 'SampleSize', ...
               SampleSize, 'BinRange', BinRange);
ok = true;

return

